@@ -1,5 +1,6 @@
 import logging
 import grpc
+import struct
 from types import TracebackType
 from typing import Iterable, List, Optional, Type
 from json import dumps
@@ -11,6 +12,7 @@ from pyfactcast.grpc.generated.FactStore_pb2 import (
     MSG_String,
     MSG_SubscriptionRequest,
     MSG_Notification,
+    MSG_UUID,
 )
 
 from pyfactcast.client.auth.basic import BasicAuth
@@ -70,9 +72,7 @@ def _construct_call_credentials(
     client_configuration: ClientConfiguration,
 ) -> Optional[grpc.CallCredentials]:
 
-    if (
-        client_configuration.credentials
-    ):  # This would be perfect for walrus but flake and mypy can  not handle that atm
+    if client_configuration.credentials:  # 3.8 Walrus
         call_credentials = grpc.metadata_call_credentials(
             BasicAuth(
                 client_configuration.credentials.username,
@@ -150,3 +150,14 @@ class FactStore:
         res = self.client.subscribe(msg)
 
         return map(Fact.from_msg, filter(_fact_filter, res))
+
+    def serial_of(self, *, fact_id: UUID) -> Optional[str]:
+        msb, lsb = struct.unpack(">qq", fact_id.bytes)
+        msg = MSG_UUID()
+        msg.lsb = lsb
+        msg.msb = msb
+        res = self.client.serialOf(msg)
+
+        if res.present:
+            return str(res.serial)
+        return None
